fn parse_catalog_item_references<'a>(a: &'a str) -> Result<Jsonb, EvalError>Expand description
Extracts the catalog item references from a catalog create_sql string as a JSONB object.
ids: array of catalog id strings from[<id> AS <name>]references.named_funcs: array of function references such as “pg_catalog”.“max”.named_types: array of type references such as “pg_catalog”.“int4”, exclusive from the ones inids.named_relations: array of relation references, exclusive from the ones inids.